
# cost_roads.py
# Popis: 
#   Tento skript vytvari ohodnoceni useku komunikaci s ohledem na morfometricke parametry reliefu(sklon), zakriveni komunikace, druh komunice a tridu.
#   Vstupnimi vrstvami jsou shape komunikaci, grid sklonu a volitelnou vrstvou je shape zastavby. Vystupem je tabulka, kter obsahuje statistick hodnoty 
#   sklonu vzhledem k jednotlivym usekum komunikace. Uzivatel take vybira datovou sadu, se kterou pracuje a pro kterou bude skript hledat druh a tridu komunikace
#   potrebnou k vypoctu. Po nacteni vstupnich vrstev a nastaveni parametru skript vypocita prumerny sklon kazdeho useku a ulozi ho do externi tabulky. Pole s
#   prumernym sklonem se pripoji k atributove tabulce shapu a nasledne podle zadane datove sady vypocita pro kazdy usek podle prumerneho sklonu a tridy komunikace 
#   prumernou rychlost automobilu na useku. Pote se zapise do noveho pole zakriveni jednotlivych useku, ktere je vypocitano jako procentualni rozdil mezi vzdusnou
#   vzdalenosti pocatecniho a koncoveho bodu useku a skutecnou delkou useku. Podle zakriveni se upravi jiz vypocitane rychlosti. Na zaver se do noveho pole zapise
#   cas potrebny pro projeti jednotlivych useku, ktery se dopocita z prumerne rychlosti a delky jednotlivych useku. Skript dokaze pracovat s datovymi sadami DMU25,
#   DMU200, ZABAGED, CEDA. Pri zadani nespecifikovane datove sady nebo datove sady, pro kterou nejsou stanoveny podminky, si uzivatel zapise do pripravene extern
#   .csv tabulky hodnoty trid komunikace, ktere jsou v jeho pouzite datove sade a algoritmus podle nich pocita.
#   Volitelnou vrstvu zastavby je vhodne pouzit pokud uzivatel nepracuje s datovou sadou DMU25.
#
# Autor: Michal LOUTHAN
# Datum: 12.8. 2010

# Import modulu pro geoprocesor
import arcgisscripting, sys

# Vytvoreni promenne pro zpristupneni nastroju geoprocessoru
gp = arcgisscripting.create()

gp.overwriteoutput = 1

# Nastaveni krokovani pri behu programu
gp.SetProgressor("step", "Ohodnocen seku komunikac...", 0, 100, 1)

# Nacteni vstupnich a vystupnich vrstev
vstup = sys.argv[1]
rastr = sys.argv[2]
tabulka = sys.argv[3]
sada=sys.argv[4]
typy=sys.argv[5]
soubor=sys.argv[6]
zastavba=sys.argv[7]
dalnice=sys.argv[8]


pole = "Value"
rychlost = "Rychlost"
cas = "Drivetime"

# Smazani duplicitnich poli
gp.deletefield(vstup, "Rychlost;Drivetime;Delka;MEAN;Zakriveni;Distance;Value;PocX;PocY;KonX;KonY")

# Vytvoreni pole pro rychlost, cas a jednoznacne ID
gp.AddField_management(vstup, pole, "long", "4")
gp.AddField_management(vstup, rychlost, "long", "4")

n=0

# Nastaveni kurzoru na vstupni vrstvu
rows = gp.UpdateCursor(vstup)

# Zacatek od prvniho radku
row = rows.Next()
     
# Vyplneni pole "Value" pro jednoznacny identifikator
while row:
        row.SetValue(pole, n+1)
        rows.UpdateRow(row)
        n=n+1
        row = rows.Next()

del row
del rows

# Podminka nacteni gridu sklonu
if gp.exists(rastr):
        
 try:
    # Overeni zapnuti extenze Spatial analyst
    gp.CheckOutExtension("Spatial")
 except:
    # Vypsani chybovou hlasku pri problemech behu skriptu
    gp.AddError("Overte zapnuti extenze Spatial Analyst")
    
 try:
    # Vytvoreni externi tabulky s hodnotami prumernych sklonu pro jednotlive useky
    gp.ZonalStatisticsAsTable_sa(vstup, "Value", rastr, tabulka, "DATA")
 
 except:
    # Vypsani chybovou hlasku pri problemech behu skriptu
    gp.AddError("nemohla byt vytvorena externi tabulka se sklony, overte zda komunikace lezi uvnitr gridu, nebo zda tabulka je nastavena ve formatu dbf")

 gp.SetProgressorPosition()   

 # Pripojeni sloupce s prumernym sklonem k atributove tabulce shapu
 try:
    gp.joinfield_management(vstup, "Value",tabulka, "Value", "Mean")
    
 except:
    gp.AddError("Nelze pripojit tabulky; overte, zda je nastavena tabulka ve formatu dbf")
         
 # Nastaveni podminek pro jednotlive datove sady s ohledem ke sklonu
 if sada == "DMU25": 

  rows = gp.UpdateCursor(vstup)
  row = rows.Next()
   
  while row:
    try:   
      tr=row.TUC1
      ob=row.TUC2
      sklon=row.MEAN
      druh=row.STYP
      trida=str(tr)
      obec=str(ob)
    except:
      gp.AddError("vstupni data neodpovidaji komunikacim z datove sady DMU 25")

    if 10 < sklon and druh == "AP010" or 10 < sklon and trida == "205": 
         row.SetValue(rychlost, "15")
    elif dalnice == "true" and trida == "2" or trida == "3" and druh == "AQ040" or druh == "AN010":
         row.SetValue(rychlost, "0")
    elif sklon < 3 and trida == "206" or druh == "AQ040" and trida == "2" or trida == "2" and obec ==  "7":
         row.SetValue(rychlost, "80")
    elif 10 < sklon and trida == "6" or 10 < sklon and trida == "7" or sklon < 3 and druh == "AP010" or 5 < sklon < 10 and druh == "AP010" or 3 < sklon < 5 and druh == "AP010" or sklon < 3 and trida == "205" or 5 < sklon < 10 and trida == "205" or 3 < sklon < 5 and trida == "205":
         row.SetValue(rychlost, "20")
    elif 3 < sklon < 5 and trida == "7" or 5 < sklon < 10 and trida == "7" or 5 < sklon < 10 and trida == "6" or sklon > 10 and trida == "204":
         row.SetValue(rychlost, "30")
    elif sklon < 3 and trida == "7" or 5 < sklon < 10 and trida == "204" or 3 < sklon < 5 and trida == "204":
         row.SetValue(rychlost, "35")
    elif sklon < 3 and trida == "6" or 3 > sklon and trida == "204" or 3 < sklon < 5 and trida == "6" or 10 < sklon and druh == "AQ040" or 10 < sklon and druh == "AQ065" or 10 < sklon and druh == "AP050" or 10 < sklon and druh == "BH070":
         row.SetValue(rychlost, "40")
    elif 5 < sklon < 10 and druh == "AQ040" or 5 < sklon < 10 and druh == "AP050" or 5 < sklon < 10 and druh == "BH070" or 5 < sklon < 10 and druh == "AQ065":
         row.SetValue(rychlost, "50")
    elif sklon > 10 and trida == "207":
         row.SetValue(rychlost, "55")
    elif 3 < sklon < 5 and trida == "207" or 5 < sklon < 10 and trida == "207" or sklon < 5 and druh == "AQ040" or sklon < 5 and druh == "AP050" or sklon < 5 and druh == "BH070" or sklon < 5 and druh == "AQ065":
         row.SetValue(rychlost, "60")
    elif sklon > 10 and trida == "206":
         row.SetValue(rychlost, "65")
    elif sklon < 3 and trida == "207":
         row.SetValue(rychlost, "70")
    elif 5 < sklon < 10 and trida == "206" or 3 < sklon < 5 and trida == "206":
         row.SetValue(rychlost, "75")
    elif 10 < sklon and trida == "2":
         row.SetValue(rychlost, "90")
    elif 5 < sklon < 10 and trida == "2":
         row.SetValue(rychlost, "100")
    elif 3 < sklon < 5 and trida == "2" or sklon < 3 and trida == "2":
         row.SetValue(rychlost, "110")
    else:
         row.SetValue(rychlost, "0")
    
    rows.UpdateRow(row)
    row = rows.Next()
      
  del row
  del rows
 
 elif sada== "DMU200":
    
  rows = gp.UpdateCursor(vstup)
  row = rows.Next()
  
  while row:

    try:
      tr=row.PTUC
      sklon=row.MEAN
      druh=row.F_CODE
      trida=str(tr)
    except:
      gp.AddError("vstupni data neodpovidaji komunikacim z datove sady DMU 200")
      

    if 10 < sklon and druh == "AP010" or 10 < sklon and trida == "205": 
         row.SetValue(rychlost, "15")
    elif dalnice == "true" and trida == "2" or trida == "3" and druh == "AQ040" or druh == "AN010":
         row.SetValue(rychlost, "0")
    elif sklon < 3 and trida == "206" or sklon > 10 and trida == "2" or druh == "AQ040" and trida == "2":
         row.SetValue(rychlost, "80")
    elif sklon < 3 and druh == "AP010" or 5 < sklon < 10 and druh == "AP010" or 3 < sklon < 5 and druh == "AP010" or sklon < 3 and trida == "205" or 5 < sklon < 10 and trida == "205" or 3 < sklon < 5 and trida == "205":
         row.SetValue(rychlost, "20")
    elif sklon > 10 and trida == "204":
         row.SetValue(rychlost, "30")
    elif 5 < sklon < 10 and trida == "204" or 3 < sklon < 5 and trida == "204":
         row.SetValue(rychlost, "35")
    elif 3 > sklon and trida == "204" or 10 < sklon and druh == "AQ040" or 10 < sklon and druh == "AQ058" or 10 < sklon and druh == "AQ542" or 3 > sklon and tr == "204":
         row.SetValue(rychlost, "40")
    elif 5 < sklon < 10 and druh == "AQ040" or 5 < sklon < 10 and druh == "AQ058" or 5 < sklon < 10 and druh == "AQ542":
         row.SetValue(rychlost, "50")
    elif sklon > 10 and trida == "207":
         row.SetValue(rychlost, "55")
    elif 3 < sklon < 5 and trida == "207" or 5 < sklon < 10 and trida == "207" or sklon < 5 and druh == "AQ040" or sklon < 5 and druh == "AQ058" or sklon < 5 and druh == "AQ542":
         row.SetValue(rychlost, "60")
    elif sklon > 10 and trida == "206":
         row.SetValue(rychlost, "65")
    elif sklon < 3 and trida == "207":
         row.SetValue(rychlost, "70")
    elif 5 < sklon < 10 and trida == "206" or 3 < sklon < 5 and trida == "206":
         row.SetValue(rychlost, "75")
    elif 10 < sklon and trida == "2":
         row.SetValue(rychlost, "90")
    elif 5 < sklon < 10 and trida == "2":
         row.SetValue(rychlost, "100")
    elif 3 < sklon < 5 and trida == "2" or sklon < 3 and trida == "2":
         row.SetValue(rychlost, "110")
    else:
         row.SetValue(rychlost, "0")
    
    rows.UpdateRow(row)
    row = rows.Next()

  del row
  del rows
  
 elif sada== "ZABAGED":
    
  rows = gp.UpdateCursor(vstup)
  row = rows.Next()
  
  while row:

    try:
      trida=row.TYPSILNICE
      sklon=row.MEAN
    except:
      gp.AddError("vstupni data neodpovidaji komunikacim z datove sady ZABAGED")
      
    if dalnice == "true" and trida == "D" or dalnice == "true" and trida == "R":
         row.SetValue(rychlost, "0")
    elif sklon < 3 and trida == "S1":
         row.SetValue(rychlost, "80")
    elif 10 < sklon and trida == "S3":
         row.SetValue(rychlost, "50")
    elif sklon > 10 and trida == "S2" or 5 < sklon < 10 and trida == "S3" :
         row.SetValue(rychlost, "55")
    elif 3 < sklon < 10 and trida == "S2" or 3 < sklon < 5 and trida == "S3":
         row.SetValue(rychlost, "60")
    elif sklon > 10 and trida == "S1" or sklon < 3 and trida == "S3":
         row.SetValue(rychlost, "65")
    elif sklon < 3 and trida == "S2":
         row.SetValue(rychlost, "70")
    elif 3 < sklon < 10 and trida == "S1":
         row.SetValue(rychlost, "75")
    elif 5 < sklon < 10 and trida == "D" or 5 < sklon < 10 and trida == "R":
         row.SetValue(rychlost, "100")
    elif sklon < 5 and trida == "D" or sklon < 5 and trida == "R":
         row.SetValue(rychlost, "110")
    elif trida == "Dv" or trida == "Dp" or trida == "Rv" or trida == "Rp" or trida == "S1v" or trida == "S1p" or trida == "S2p" or trida == "S2v" or trida == "S3p" or trida == "S3v":
         row.SetValue(rychlost, "40")
    else:
         row.SetValue(rychlost, "0")
    
    rows.UpdateRow(row)
    row = rows.Next()

  del row
  del rows
  
 elif sada== "CR 150":
    
  rows = gp.UpdateCursor(vstup)
  row = rows.Next()
  
  while row:
          
    try:
      tr=row.ROAD_CLASS
      sklon=row.MEAN
      trida=str(tr)
    except:
      gp.AddError("vstupni data neodpovidaji komunikacim z datove sady CR 150")         
    
    if dalnice == "true" and trida == "0":
         row.SetValue(rychlost, "0")
    elif sklon < 3 and trida == "1":
         row.SetValue(rychlost, "80")
    elif 10 < sklon and trida == "3":
         row.SetValue(rychlost, "50")
    elif sklon > 10 and trida == "2" or 5 < sklon < 10 and trida == "3" :
         row.SetValue(rychlost, "55")
    elif 3 < sklon < 10 and trida == "2" or 3 < sklon < 5 and trida == "3":
         row.SetValue(rychlost, "60")
    elif sklon > 10 and trida == "1" or sklon < 3 and trida == "3":
         row.SetValue(rychlost, "65")
    elif sklon < 3 and trida == "2":
         row.SetValue(rychlost, "70")
    elif 3 < sklon < 10 and trida == "1":
         row.SetValue(rychlost, "75")
    elif 5 < sklon < 10 and trida == "0":
         row.SetValue(rychlost, "100")
    elif sklon < 5 and trida == "0":
         row.SetValue(rychlost, "110")
    elif trida == "4" or trida == "5":
         row.SetValue(rychlost, "40")
    else:
         row.SetValue(rychlost, "0")
    
    rows.UpdateRow(row)
    row = rows.Next()

  del row
  del rows
  
 elif sada == "jin datov sada":
   
  try:
      f = open(soubor, "rt")
  except:
      gp.AddError("zadejte cestu k csv souboru")

  try:
    try:
      for line in f:
          dalnice, prvni, druha, treti, ucelova, zpevnena, polni, most, obec, ostatni, zeleznice = line.split(",")
    except:
      gp.AddError("v csv souboru jsou zadany spatne hodnoty, informujte se v manualu")
  finally:
    f.close()

  rows = gp.UpdateCursor(vstup)
  row = rows.Next()

  while row:
    try:
      tr=row.GetValue(typy)
      trida=str(tr)
      sklon=row.MEAN
    except:
      gp.AddError("vyberte pole s oznacenim typu komunikace v pouzite vrstve komunikaci")
      
    if 10 < sklon and trida == polni or 10 < sklon and trida == zpevnena: 
         row.SetValue(rychlost, "15")
    elif dalnice == "true" and trida == dalnice:
         row.SetValue(rychlost, "0")
    elif sklon < 3 and trida == prvni:
         row.SetValue(rychlost, "80")
    elif 10 < sklon and trida == obec or sklon < 10 and trida == polni or sklon < 10 and trida == zpevnena:
         row.SetValue(rychlost, "20")
    elif 5 < sklon < 10 and trida == obec or sklon > 10 and trida == ucelova:
         row.SetValue(rychlost, "30")
    elif 3 < sklon < 10 and trida == ucelova:
         row.SetValue(rychlost, "35")
    elif sklon < 5 and trida == obec or 3 > sklon and trida == ucelova or 10 < sklon and trida == most or trida == ostatni:
         row.SetValue(rychlost, "40")
    elif 5 < sklon < 10 and trida == most or sklon > 10 and trida == treti:
         row.SetValue(rychlost, "50")
    elif sklon > 10 and trida == druha or 5 < sklon < 10 and trida == treti:
         row.SetValue(rychlost, "55")
    elif 3 < sklon < 10 and trida == druha or sklon < 5 and trida == most or 3 < sklon < 5 and trida == treti:
         row.SetValue(rychlost, "60")
    elif sklon > 10 and trida == prvni or sklon < 3 and trida == treti:
         row.SetValue(rychlost, "65")
    elif sklon < 3 and trida == druha:
         row.SetValue(rychlost, "70")
    elif 3 < sklon < 10 and trida == prvni:
         row.SetValue(rychlost, "75")
    elif 10 < sklon and trida == dalnice:
         row.SetValue(rychlost, "90")
    elif 5 < sklon < 10 and trida == dalnice:
         row.SetValue(rychlost, "100")
    elif sklon < 5 and trida == dalnice:
         row.SetValue(rychlost, "110")
    else:
         row.SetValue(rychlost, "0")
    
    rows.UpdateRow(row)
    row = rows.Next()

  del row
  del rows

# Podminky pro vypocet bez ohledu sklonu
else:
 if sada == "DMU25": 

  rows = gp.UpdateCursor(vstup)
  row = rows.Next()
   
  while row:
          
    try:  
      tr=row.TUC1
      druh=row.STYP
      trida=str(tr)
    except:
      gp.AddError("vstupni data neodpovidaji komunikacim z datove sady DMU 25")
      
    if dalnice == "true" and trida == "2" or trida == "3" and druh == "AQ040" or druh == "AN010":
         row.SetValue(rychlost, "0")
    elif druh == "AQ040" and trida == "2":
         row.SetValue(rychlost, "80")
    elif trida == "205" or druh == "AP010":
         row.SetValue(rychlost, "20")
    elif trida == "7":
         row.SetValue(rychlost, "35")
    elif trida == "6" or trida == "204":
         row.SetValue(rychlost, "40")
    elif trida == "207":
         row.SetValue(rychlost, "55")
    elif druh == "AQ040" or druh == "AP050" or druh == "BH070" or druh == "AQ065":
         row.SetValue(rychlost, "60")
    elif trida == "206":
         row.SetValue(rychlost, "75")
    elif trida == "2":
         row.SetValue(rychlost, "90")
    else:
         row.SetValue(rychlost, "0")
    
    rows.UpdateRow(row)
    row = rows.Next()

  del row
  del rows
 
 elif sada== "DMU200":
    
  rows = gp.UpdateCursor(vstup)
  row = rows.Next()
  
  while row:
          
    try:
      tr=row.PTUC
      druh=row.F_CODE
      trida=str(tr)
    except:
      gp.AddError("vstupni data neodpovidaji komunikacim z datove sady DMU 200")
      
    if dalnice == "true" and trida == "2" or trida == "3" and druh == "AQ040" or druh == "AN010":
         row.SetValue(rychlost, "0")
    elif druh == "AQ040" and trida == "2":
         row.SetValue(rychlost, "80")
    elif trida == "205" or druh == "AP010":
         row.SetValue(rychlost, "20")
    elif trida == "7":
         row.SetValue(rychlost, "35")
    elif trida == "6" or trida == "204":
         row.SetValue(rychlost, "40")
    elif trida == "207":
         row.SetValue(rychlost, "55")
    elif druh == "AQ040" or druh == "AQ058" or druh == "AQ542":
         row.SetValue(rychlost, "60")
    elif trida == "206":
         row.SetValue(rychlost, "75")
    elif trida == "2":
         row.SetValue(rychlost, "90")
    else:
         row.SetValue(rychlost, "0")
    
    rows.UpdateRow(row)
    row = rows.Next()

  del row
  del rows
  
 elif sada== "ZABAGED":
    
  rows = gp.UpdateCursor(vstup)
  row = rows.Next()
  
  while row:
          
    try:
      trida=row.TYPSILNICE
    except:
      gp.AddError("vstupni data neodpovidaji komunikacim z datove sady ZABAGED")
      
    if dalnice == "true" and trida == "D" or dalnice == "true" and trida == "R":
         row.SetValue(rychlost, "0")
    elif trida == "S3" or trida == "Dv" or trida == "Dp" or trida == "Rv" or trida == "Rp" or trida == "S1v" or trida == "S1p" or trida == "S2p" or trida == "S2v" or trida == "S3p" or trida == "S3v":
         row.SetValue(rychlost, "40")
    elif trida == "S2":
         row.SetValue(rychlost, "55")
    elif trida == "S1":
         row.SetValue(rychlost, "75")
    elif trida == "D" or trida == "R":
         row.SetValue(rychlost, "90")
    else:
         row.SetValue(rychlost, "0")
    
    rows.UpdateRow(row)
    row = rows.Next()

  del row
  del rows
  
 elif sada== "CR 150":
    
  rows = gp.UpdateCursor(vstup)
  row = rows.Next()
  
  while row:
          
    try:
      tr=row.ROAD_CLASS
      trida=str(tr)
    except:
      gp.AddError("vstupni data neodpovidaji komunikacim z datove sady CR 150")
      
    if dalnice == "true" and trida == "0":
         row.SetValue(rychlost, "0")
    elif trida == "3" or trida == "4" or trida == "5":
         row.SetValue(rychlost, "40")
    elif trida == "2":
         row.SetValue(rychlost, "55")
    elif trida == "1":
         row.SetValue(rychlost, "75")
    elif trida == "0":
         row.SetValue(rychlost, "90")
    else:
         row.SetValue(rychlost, "0")
    
    rows.UpdateRow(row)
    row = rows.Next()

  del row
  del rows
  
 elif sada == "jin datov sada":

  try:   
    f = open(soubor, "rt")
  except:
    gp.AddError("zadejte cestu k csv souboru")

  try:

    try:
      for line in f:
          dalnice, prvni, druha, treti, ucelova, zpevnena, polni, most, obec, ostatni, zeleznice = line.split(",")
    except:
      gp.AddError("v csv souboru jsou zadany spatne hodnoty, informujte se v manualu")   

  finally:
    f.close()

  rows = gp.UpdateCursor(vstup)
  row = rows.Next()

  while row:

    try:
      tr=row.GetValue(typy)
      trida=str(tr)
    except:
      gp.AddError("vyberte pole s oznacenim typu komunikace v pouzite vrstve komunikaci")
      
    if dalnice == "true" and trida == dalnice:
         row.SetValue(rychlost, "0")
    elif trida == zpevnena or trida == polni:
         row.SetValue(rychlost, "20")
    elif trida == obec or trida == ucelova or trida == treti:
         row.SetValue(rychlost, "40")
    elif trida == druha:
         row.SetValue(rychlost, "55")
    elif trida == most:
         row.SetValue(rychlost, "60")
    elif trida == prvni:
         row.SetValue(rychlost, "75")
    elif trida == dalnice:
         row.SetValue(rychlost, "90")
    else:
         row.SetValue(rychlost, "0")
    
    rows.UpdateRow(row)
    row = rows.Next()

  del row
  del rows
  
gp.SetProgressorPosition()

# Vytvoreni poli pro vypocet souradnic pocatecnich a koncovych bodu useku, delek a zakriveni
gp.AddField_management(vstup, "PocX", "FLOAT", 18, 11)
gp.AddField_management(vstup, "PocY", "FLOAT", 18, 11)
gp.AddField_management(vstup, "KonX", "FLOAT", 18, 11)
gp.AddField_management(vstup, "KonY", "FLOAT", 18, 11)
gp.AddField_management(vstup, "Delka", "FLOAT", 18, 4)
gp.AddField_management(vstup, "Distance", "FLOAT", 18, 4)
gp.AddField_management(vstup, "Zakriveni", "FLOAT", 18, 11)

gp.SetProgressorPosition()

# Nacteni souradnic prvniho a posledniho bodu useku
try:
  xPoc = "!SHAPE.FIRSTPOINT!.split()[0]"
  yPoc = "!SHAPE.FIRSTPOINT!.split()[1]"
  xKon = "!SHAPE.LASTPOINT!.split()[0]"
  yKon = "!SHAPE.LASTPOINT!.split()[1]"
except:
  gp.AddError("vstupni vrstva neni liniova")
  
# Vzorce pro vypocet prime vzdalenosti mezi poc a konc bodem useku a zakriveni
distance = "Sqr (([PocX] - [KonX])^2+([PocY] - [KonY])^2)"
zakriv = "100*([Delka]-[Distance])/[Distance]"

gp.SetProgressorPosition()

# Vypocet skutecne delky useku
rows = gp.UpdateCursor(vstup)
row = rows.Next()

while row:
    
    feat = row.shape
    delka = feat.Length
    row.SetValue("Delka", delka)
    rows.UpdateRow(row)
    row = rows.Next()

del row
del rows

# Zapsani souradnic, delky a zakriveni do atributove tabulky
gp.CalculateField_management(vstup, "PocX", xPoc, "PYTHON")
gp.CalculateField_management(vstup, "PocY", yPoc, "PYTHON")
gp.CalculateField_management(vstup, "KonX", xKon, "PYTHON")
gp.CalculateField_management(vstup, "KonY", yKon, "PYTHON")
gp.CalculateField_management(vstup, "Distance", distance, "VB")
gp.CalculateField_management(vstup, "Zakriveni", zakriv, "VB")

gp.SetProgressorPosition()

# Uprava rychlosti pro useky lezici v zastavbe
try:
  if gp.exists(zastavba):
      
      gp.MakeFeatureLayer(vstup, "kom_lyr") 
      gp.SelectLayerByLocation_management("kom_lyr", "COMPLETELY_WITHIN", zastavba)

      rows = gp.UpdateCursor("kom_lyr")
      row = rows.Next()
 
      while row:

          row.SetValue(rychlost, "40")
              
          rows.UpdateRow(row)
   
          row = rows.Next()

      del row
      del rows
    
except:
    gp.AddError("zadana vrstva obci neni polygonova")
    
gp.SetProgressorPosition()

# Finalni uprava rychlosti podle zakriveni
rows = gp.UpdateCursor(vstup)
row = rows.Next()

while row:
    speed=row.Rychlost
    kriv=row.Zakriveni
         
    if speed == 15:
         row.SetValue(rychlost, "25")
    elif speed == 20:
         row.SetValue(rychlost, "30")
    elif speed == 30 and kriv < 5 or speed == 35 and kriv > 5:
         row.SetValue(rychlost, "40")
    elif speed == 30 and kriv > 5:
         row.SetValue(rychlost, "35")
    elif speed == 35 and kriv < 5 or speed == 40 and kriv > 5:
         row.SetValue(rychlost, "45")
    elif speed == 40 and kriv < 5:
         row.SetValue(rychlost, "50")
    elif speed == 50 and kriv > 5:
         row.SetValue(rychlost, "55")
    elif speed == 50 and kriv < 5 or speed == 55 and kriv > 5 or speed == 60 and kriv > 5 or speed == 65 and kriv > 5:
         row.SetValue(rychlost, "60")
    elif speed == 55 and kriv < 5:
         row.SetValue(rychlost, "65")
    elif speed == 60 and kriv < 5 or speed == 65 and 2 < kriv < 5 or speed == 70 and kriv > 5:
         row.SetValue(rychlost, "70")
    elif speed == 65 and kriv < 2 or speed == 75 and kriv > 5:
         row.SetValue(rychlost, "75")
    elif speed == 70 and kriv < 5 or speed == 75 and 2 < kriv < 5 or speed == 80 and kriv > 2 or speed == 70 and trida == "2":
         row.SetValue(rychlost, "80")
    elif speed == 75 and kriv < 2:
         row.SetValue(rychlost, "85")
    elif speed == 80 and kriv < 2:
         row.SetValue(rychlost, "90")
    elif speed == 90:
         row.SetValue(rychlost, "100")
    elif speed == 100:
         row.SetValue(rychlost, "110")
    elif speed == 110:
         row.SetValue(rychlost, "115")
    else:
         row.SetValue(rychlost, "0")
         
    rows.UpdateRow(row)
    row = rows.Next()

del row
del rows

gp.SetProgressorPosition()

gp.AddField_management(vstup, cas, "long", "4")

rows = gp.UpdateCursor(vstup)
row = rows.Next()

while row:
    speed=row.Rychlost
    delka=row.Delka
    
    if speed == 0:
        row.SetValue(cas, 9999)
    else:
        time = delka/speed*3.6
        row.SetValue(cas, time)
        
    rows.UpdateRow(row)
    row = rows.Next()

del row
del rows

# Smazani prebytecnych poli
gp.deletefield (vstup, "PocX; PocY; KonX; KonY; Distance; Value")


gp.SetProgressorPosition()
